@@ -66,7 +66,9 @@ public:
 	Babylon();
 	~Babylon();
 
-	QTime t;	//ooo
+	QTime t;		//ooo
+	ifstream file_eng;	//ooo
+	ifstream file_spec;	//ooo
 
 	//bool translate(QString ,QList<Item> &);
 	bool translate(QString ,QList<Item> &, QString);   //ooo
@@ -90,8 +92,8 @@ private:
 	QDataStream *stream_eng;
 	QDataStream *stream_spec;
 	*/
-	ifstream file_eng;
-	ifstream file_spec;
+	//ifstream file_eng;
+	//ifstream file_spec;
 	
 	long word_index(QString word);
 	QString bab_to_char_jap_2(int lsb, int msb);	//ooo
