@@ -147,40 +147,44 @@ const std::string partOfSpeech[] = {
 };
 */
 
-const std::string partOfSpeech[] = {	//ooo
-	"<i>n.</i>",
-	"<i>adj.</i>",
-	"<i>v.</i>",
-	"<i>adv.</i>",
-	"<i>interj.</i>",
-	"<i>pron.</i>",
-	"<i>prep.</i>",
-	"<i>conj.</i>",
-	"<i>suff.</i>",
-	"<i>pref.</i>",
-	"<i>art.</i>",
-	"?11.",			//ooo
-        "<i>init.</i>",		//ooo	12
-	"<i>adj./n.</i>",	//ooo	13
-	"<i>adj./n.</i>",	//ooo	14
-	"<i>adj./n.</i>",	//ooo	15
-	"<i>nf.</i>",		//ooo	16
-	"<i>nmf.</i>",		//ooo	17
-	"<i>nm.</i>"		//ooo	18
+const std::wstring partOfSpeech[] = {	//ooo
+	L"<i>n.</i>",
+	L"<i>adj.</i>",
+	L"<i>v.</i>",
+	L"<i>adv.</i>",
+	L"<i>interj.</i>",
+	L"<i>pron.</i>",
+	L"<i>prep.</i>",
+	L"<i>conj.</i>",
+	L"<i>suff.</i>",
+	L"<i>pref.</i>",
+	L"<i>art.</i>",
+	L"?11.",			//ooo
+        L"<i>init.</i>",		//ooo	12
+	L"<i>adj./n.</i>",	//ooo	13
+	L"<i>adj./n.</i>",	//ooo	14
+	L"<i>adj./n.</i>",	//ooo	15
+	L"<i>nf.</i>",		//ooo	16
+	L"<i>nmf.</i>",		//ooo	17
+	L"<i>nm.</i>"		//ooo	18
 };
 
 
 typedef struct {
 	unsigned type;
 	unsigned length;
-	char * data;
+	//char * data;
+	unsigned char * data;	//ooo
 } bgl_block;
 
 
 typedef struct {
-        std::string headword;
-        std::string definition;
-        std::vector<std::string> alternates;
+	//std::string headword;
+	//std::string definition;
+	//std::vector<std::string> alternates;
+	std::wstring headword;			//ooo
+	std::wstring definition;		//ooo
+	std::vector<std::wstring> alternates;	//ooo
 } bgl_entry;
 
 
