@@ -61,6 +61,7 @@
 
 //#define DEBUG_4c
 //#define DEBUG_4d
+//#define DEBUG_5
 
 QTrans::QTrans(QWidget *parent, KAboutData *aboutData) : KMainWindow(parent)
 {
@@ -92,6 +93,7 @@ QTrans::QTrans(QWidget *parent, KAboutData *aboutData) : KMainWindow(parent)
 	connect(Out, SIGNAL(loadProgress(int)), progressBar, SLOT(show()));		//ooo
 	connect(Out, SIGNAL(loadProgress(int)), progressBar, SLOT(setValue(int)));	//ooo
 	connect(Out, SIGNAL(loadFinished(bool)), progressBar, SLOT(hide()));		//ooo
+	connect(Out, SIGNAL(loadFinished(bool)), this, SLOT(slot_statusBarMessage()));		//ooo
 
 	createActions();
 	createMenus();
@@ -296,6 +298,34 @@ void QTrans::createStatusBar()			//ooo
 }
 
 
+void QTrans::slot_statusBarMessage()			//ooo
+{
+
+	#ifdef DEBUG_5
+		qDebug() << "ProgresBar finished";
+	#endif
+
+	//QString str = QString(" : Finished: (%1) ms").arg(t.elapsed());
+
+	if (StatusBarSelected) {
+
+		/*QString str = QString("%1 Finished: %2 ms").arg(" * ").arg(t.elapsed());
+
+		//strStatusBar += " : Finished";
+
+		strStatusBar += str;
+		//QMainWindow::statusBar()->showMessage(tr("Finished"));
+		QMainWindow::statusBar()->showMessage(strStatusBar);	//ooo
+*/
+		FinishedTime = t.elapsed();
+
+		strStatusBar = QString("Time elapsed: %1 ms %2 %3 %4 Number of lines: %5 %6 Finished: %7 ms").arg(SearchTime).arg(" * ").arg(DictionaryName).arg(" * ").arg(NumOfLines).arg(" * ").arg(FinishedTime);
+		QMainWindow::statusBar()->showMessage(strStatusBar);	//ooo
+
+	}
+}
+
+
 void QTrans::mousePressEvent(QMouseEvent *event)	//ooo
 {
 /*	KMessageBox::sorry(this, i18n("mousePressEvent!"));
@@ -371,7 +401,7 @@ void QTrans::mousePressEvent(QMouseEvent *event)	//ooo
 void QTrans::Translate(QString EngWord, int ind, bool allDict, bool inEveryDict)	//ooo
 {
 
-	QString strStatusBar;		//ooo
+	//QString strStatusBar;		//ooo
 	QString strTimeElapsed;		//ooo
 	QString text_check;		//ooo
 	int comboIndex = -1;		//ooo
@@ -508,9 +538,11 @@ void QTrans::Translate(QString EngWord, int ind, bool allDict, bool inEveryDict)
 	//strStatusBar.sprintf("Time elapsed: %d ms	%s", t.elapsed(), "Dictionary Name");	//ooo
 
 	if (StatusBarSelected) {
+		SearchTime = t.elapsed();
+		DictionaryName = Item.fileName.section("/", -1);
 		//strStatusBar = QString("Time elapsed: %1 ms %2 %3").arg(t.elapsed()).arg("	").arg(Item.fileName.section("/", -1));		//ooo
 		//strStatusBar = QString("Time elapsed: %1 ms %2 %3 %4 %5 %6").arg(t.elapsed()).arg(" * ").arg(Item.fileName.section("/", -1)).arg(" * ").arg("Number of lines: ").arg(NumOfLines);		//ooo
-		strStatusBar = QString("Time elapsed: %1 ms %2 %3 %4 Number of lines: %6").arg(t.elapsed()).arg(" * ").arg(Item.fileName.section("/", -1)).arg(" * ").arg(NumOfLines);		//ooo
+		strStatusBar = QString("Time elapsed: %1 ms %2 %3 %4 Number of lines: %5").arg(SearchTime).arg(" * ").arg(DictionaryName).arg(" * ").arg(NumOfLines);		//ooo
 		//strStatusBar = QString("Time elapsed: %1 ms * %2 * Number of lines: %3").arg(t.elapsed()).arg(Item.fileName.section("/", -1)).arg(NumOfLines);		//ooo
 		QMainWindow::statusBar()->showMessage(strStatusBar);	//ooo
 		//QMainWindow::statusBar()->addWidget(progressBar);	//ooo
