@@ -47,9 +47,13 @@
 #include <QMouseEvent>
 #include <QPoint>
 
+#include <KDebug>	//ooo
+
 #include "settings_widg.h"
 #include "utils.h" //where is defined the FlagsID array
 
+//#define DEBUG_1
+
 //Settings_widg::Settings_widg( QWidget *parent ) :
 Settings_widg::Settings_widg( QWidget *parent, QMouseEvent *event ) :	//ooo
 	QWidget( parent )
@@ -103,17 +107,22 @@ Settings_widg::Settings_widg( QWidget *parent, QMouseEvent *event ) :	//ooo
 	bottomBox = new QHBoxLayout(this);
 	bAdd = new KPushButton(i18n("&Add"),this);
 	bRemoveAll = new KPushButton(i18n("&Remove All"),this);
-	bMoveUp = new KPushButton(KIcon("go-up"),i18n("Up"),this);	//ooo
-	bMoveDown = new KPushButton(KIcon("go-down"),i18n("Down"),this);	//ooo
+	bMoveUp = new KPushButton(KIcon("go-up"),i18n("Up"),this);			//ooo
+	bMoveDown = new KPushButton(KIcon("go-down"),i18n("Down"),this);		//ooo
+	bMoveToLine = new KPushButton(KIcon("go-jump"),i18n("Move to Line"),this);	//ooo
+	cGoToLine = new KComboBox(this);						//ooo
 	bHelp = new KPushButton(i18n("&Help"),this);
 
 	bottomBox->setSpacing(5);
 	bottomBox->addWidget(bAdd);
 	//bottomBox->addWidget(bScan);
 	bottomBox->addWidget(bRemoveAll);
-	bottomBox->addStretch();	//ooo
-	bottomBox->addWidget(bMoveUp);	//ooo
+	bottomBox->addStretch();		//ooo
+	bottomBox->addWidget(bMoveUp);		//ooo
 	bottomBox->addWidget(bMoveDown);	//ooo
+	bottomBox->addStretch();		//ooo
+	bottomBox->addWidget(bMoveToLine);	//ooo
+	bottomBox->addWidget(cGoToLine);	//ooo
 	bottomBox->addStretch();
 	bottomBox->addWidget(bHelp);
 
@@ -141,13 +150,15 @@ Settings_widg::Settings_widg( QWidget *parent, QMouseEvent *event ) :	//ooo
 	moveOnTopAct = new QAction(KIcon("go-top"/*"arrow-up-double"*/), tr("Move on &Top"), this);
 	moveUpAct = new QAction(KIcon("go-up"/*"arrow-up"*/), tr("Move &Up"), this);
 	moveDownAct = new QAction(KIcon("go-down"/*"arrow-down"*/), tr("Move &Down"), this);
+	moveToLineAct = new QAction(KIcon("go-down"/*"arrow-down"*/), tr("Move to Line"), this);
 	editAct = new QAction(KIcon("document-properties"), tr("&Edit"), this);
 	removeDictionaryAct = new QAction(KIcon("edit-delete"), tr("&Remove dictionary"), this);
 
 	connect(bAdd,SIGNAL(clicked()),this,SLOT(slot_Add()));
 	connect(bRemoveAll,SIGNAL(clicked()),this,SLOT(slot_RemoveAll()));
-	connect(bMoveUp,SIGNAL(clicked()),this,SLOT(slot_moveUp()));	//ooo
+	connect(bMoveUp,SIGNAL(clicked()),this,SLOT(slot_moveUp()));		//ooo
 	connect(bMoveDown,SIGNAL(clicked()),this,SLOT(slot_moveDown()));	//ooo
+	connect(bMoveToLine,SIGNAL(clicked()),this,SLOT(slot_moveToLine()));	//ooo
 	connect(bHelp,SIGNAL(clicked()),this,SLOT(slot_Help()));
 	connect(bOpen,SIGNAL(clicked()),this,SLOT(slot_Open()));
 	//connect(Table,SIGNAL(clicked(int,int,int,const QPoint &)),
@@ -181,8 +192,23 @@ Settings_widg::Settings_widg( QWidget *parent, QMouseEvent *event ) :	//ooo
 		flagPath = (*it);   //with this error with "Exit" button in toolbar
 	//QMessageBox::about(this, i18n("About Menu"), QString("%1").arg((*it)));
 
-	bMoveUp->setEnabled(false);	//ooo
-	bMoveDown->setEnabled(false);	//ooo
+	bMoveUp->setEnabled(false);			//ooo
+	bMoveDown->setEnabled(false);			//ooo
+	bMoveToLine->setEnabled(false);			//ooo
+
+	cGoToLine->addItem(i18n("None"), tr(""));	//ooo
+
+	//QString stringGoToLine = "";
+
+	//for (int i = 0; i <= Data->count(); i++) {	//ooo
+	//for (int i = 0; i <= tableWidget->rowCount(); i++) {	//ooo
+	//for (int i = 0; i <= 5; i++) {	//ooo
+		//stringGoToLine = i;
+		//cGoToLine->addItem(stringGoToLine);
+		//cGoToLine->setItemText(i,i);
+	//}
+
+	//cGoToLine->setMaxCount(Data->count());
 
 }
 
@@ -268,6 +294,15 @@ void Settings_widg::slot_table_Clicked(int row, int column)
 		bMoveDown->setEnabled(true);
 	}
 
+	if (selectedRow >= 0) {					//ooo
+		cGoToLine-> setCurrentIndex(selectedRow+1);
+		bMoveToLine->setEnabled(true);
+	}
+
+	//if (selectedRow=cGoToLine->currentIndex()-1) {	//ooo
+	//	bMoveToLine->setEnabled(false);
+	//}
+
 	//QMouseEvent* mouseEvent;
 	//QPoint point = mouseEvent->pos();
 	//QTreeWidgetItem* current = ui.treeWidget->itemAt(mouseEvent->pos());
@@ -372,13 +407,17 @@ void Settings_widg::slot_moveUp()
 		bMoveUp->setEnabled(false);
 	}
 
+	if (selectedRow >= 0) {					//ooo
+		cGoToLine-> setCurrentIndex(selectedRow+1);
+	}
+
 	//repaintTable();
 }
 
 
 void Settings_widg::slot_moveDown()
 {
-	if (selectedRow == 0) {	//ooo
+	if (selectedRow == 0) {						//ooo
 		bMoveUp->setEnabled(true);
 	}
 
@@ -404,22 +443,81 @@ void Settings_widg::slot_moveDown()
 
 	Data->move(selectedRow, selectedRow+1);
 	repaintTable();
-	if (selectedRow >= tableWidget->rowCount()-2) {	//ooo
+	if (selectedRow >= tableWidget->rowCount()-2) {			//ooo
         	tableWidget->setCurrentCell(selectedRow+1,0);
 	} else {
         	tableWidget->setCurrentCell(selectedRow+2,0);
 	}
-	selectedRow = selectedRow+1;	//ooo
+	selectedRow = selectedRow+1;					//ooo
 	prevItem = tableWidget->item(selectedRow-1,selectedColumn);	//ooo
 	currentItem = tableWidget->item(selectedRow,selectedColumn);	//ooo
-	currentItem->setBackground(tableItemColor);	//ooo
-	prevItem->setBackground(palette().base()); //ooo
-	prevItem = currentItem;	//ooo
+	currentItem->setBackground(tableItemColor);			//ooo
+	prevItem->setBackground(palette().base()); 			//ooo
+	prevItem = currentItem;						//ooo
 
-	if (selectedRow == tableWidget->rowCount()-1) {	//ooo
+	if (selectedRow == tableWidget->rowCount()-1) {			//ooo
 		bMoveDown->setEnabled(false);
 	}
 
+	if (selectedRow >= 0) {						//ooo
+		cGoToLine-> setCurrentIndex(selectedRow+1);
+	}
+
+	//repaintTable();
+}
+
+
+void Settings_widg::slot_moveToLine()
+{
+/*	if (selectedRow == tableWidget->rowCount()-1) {	//ooo
+		bMoveDown->setEnabled(true);
+	}
+
+	if (selectedRow == cGoToLine->currentIndex()-1) {	//ooo
+		bMoveToLine->setEnabled(false);
+	}
+*/
+	//Data->move(selectedRow, selectedRow-1);
+
+#ifdef DEBUG_1
+	qDebug() << "selectedRow = " << selectedRow;
+	qDebug() << "cGoToLine->currentIndex() = " << cGoToLine->currentIndex();
+#endif
+
+
+	if (cGoToLine->currentIndex() != 0 && selectedRow != cGoToLine->currentIndex()-1) {
+		Data->move(selectedRow,cGoToLine->currentIndex()-1);
+		repaintTable();
+        	tableWidget->setCurrentCell(cGoToLine->currentIndex()-1,0);	//ooo
+		prevItem = tableWidget->item(selectedRow,selectedColumn);	//ooo
+		selectedRow = cGoToLine->currentIndex()-1;			//ooo
+		currentItem = tableWidget->item(selectedRow,selectedColumn);	//ooo
+		currentItem->setBackground(tableItemColor);			//ooo
+		prevItem->setBackground(palette().base()); 			//ooo
+		prevItem = currentItem;						//ooo
+	}
+
+/*	Data->move(selectedRow, selectedRow-1);
+	repaintTable();
+        tableWidget->setCurrentCell(selectedRow,0);			//ooo
+	selectedRow = selectedRow-1;	//ooo
+	prevItem = tableWidget->item(selectedRow+1,selectedColumn);	//ooo
+	currentItem = tableWidget->item(selectedRow,selectedColumn);	//ooo
+	currentItem->setBackground(tableItemColor);			//ooo
+	prevItem->setBackground(palette().base()); 			//ooo
+	prevItem = currentItem;						//ooo
+*/
+	if (selectedRow == 0) {							//ooo
+		bMoveUp->setEnabled(false);
+		bMoveDown->setEnabled(true);
+	} else if (selectedRow == tableWidget->rowCount()-1) {			//ooo
+		bMoveUp->setEnabled(true);
+		bMoveDown->setEnabled(false);
+	} else {
+		bMoveUp->setEnabled(true);
+		bMoveDown->setEnabled(true);
+	}
+
 	//repaintTable();
 }
 
@@ -429,15 +527,16 @@ void Settings_widg::slot_moveOnTop()
 	Data->move(selectedRow, 0);
 	repaintTable();
 
-	if (selectedRow == tableWidget->rowCount()-1) {	//ooo
+	if (selectedRow == tableWidget->rowCount()-1) {		//ooo
 		bMoveDown->setEnabled(true);
 	}
 
-	bMoveUp->setEnabled(false);	//ooo
-	selectedRow = 0;	//ooo
+	bMoveUp->setEnabled(false);				//ooo
+	selectedRow = 0;					//ooo
+	cGoToLine-> setCurrentIndex(selectedRow+1);		//ooo
 	currentItem = tableWidget->item(0,selectedColumn);	//ooo
-	currentItem->setBackground(tableItemColor);	//ooo
-	prevItem = currentItem;	//ooo
+	currentItem->setBackground(tableItemColor);		//ooo
+	prevItem = currentItem;					//ooo
 }
 
 
@@ -631,7 +730,7 @@ CAddWidget::CAddWidget(Settings_widg *parent, int _row,
 
 	setMinimumSize(300, 150);
 	//resize(440, 300);
-	resize(540, 350);
+	resize(670, 370);
 	//Box = new QVBoxLayout(this);
 	mainLayout = new QVBoxLayout(this);
 
@@ -668,7 +767,7 @@ CAddWidget::CAddWidget(Settings_widg *parent, int _row,
 	cDisable = new KComboBox(this);
 	Box8->setSpacing(5);
 	Box8->addWidget(Label8);
-	Box8->setSpacing(100);
+	Box8->setSpacing(75);
 	Box8->addWidget(cDisable);
 	Box8->addStretch();
 
